==> ssp-center-api-0.5.93sjq-20191029.101022-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActivityManualPlanDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ActivityManualPlanDto
 */
public class ActivityManualPlanDto extends BaseDto {

    private static final long serialVersionUID = -5433858401741977928L;

    /** 未开始 */
    public static final int   STATUS_PREVIEW   = 0;

    /** 正在投放 */
    public static final int   STATUS_RELEASE   = 1;

    /** 已过期 */
    public static final int   STATUS_EXPIRED   = 2;

    /** 计划类型 0-活动 */
    public static final int   PLAN_TYPE_ACT    = 0;

    /** 计划类型 1-主会场 */
    public static final int   PLAN_TYPE_VENUE  = 1;

    private Long              activityId;

    private Integer           activityType;

    private String            activityName;

    private String            activityUrl;

    private Integer           activityStatus;

    private Long              operatorActivityId;

    private String            releaseTime;

    private Integer           status;

    private Long              slotId;

    private Integer           planType;

    /** 活动来源 0-兑吧 1-推啊 2-流量引导页 */
    private Integer           actSource;

    /** 手动投放 投放方式 0 轮询，1 定时 */
    private Integer           launchType;

    /** 测试广告位子投放方式: 仅投1 优投人工2 优投算法3 纯算法4 其他0 */
    private Integer           subActivityWay;

    /** 屏蔽活动状态 */
    private Integer           shieldActTagFlag;

    /** 活动皮肤类型 */
    private String            subType;

    /** 活动皮肤名称 */
    private String            skinName;

    /** 是否是海外活动 0正常 1海外 */
    private Integer           overseas;

    /**
     * 活动测试计划ID
     */
    private Long              planId;

    /**
     * 是否是测试活动类型
     */
    private Integer           isTestActivityType;

    /**
     * 广告位地域类型ID
     */
    private Long regionId;

    /**
     * 是否支持增值 0-否 1-是
     */
    private Integer isEnc;

    /**
     * 所属组
     */
    private Byte belongToGroup;

    /**
     * 定时投放活动 测试开关
     */
    private Byte actPlanStatus;

    private Boolean  notice = false;

    /** 屏蔽活动皮肤状态 1-被当前广告位屏蔽 */
    private Integer shieldActSkinTagFlag;

    public Boolean getNotice() {
        return notice;
    }

    public void setNotice(Boolean notice) {
        this.notice = notice;
    }


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Integer getIsTestActivityType() {
        return isTestActivityType;
    }

    public void setIsTestActivityType(Integer isTestActivityType) {
        this.isTestActivityType = isTestActivityType;
    }

    /**
     * actSource.
     *
     * @return the actSource
     * @since JDK 1.6
     */
    public Integer getActSource() {
        return actSource;
    }

    /**
     * actSource.
     *
     * @param actSource the actSource to set
     * @since JDK 1.6
     */
    public void setActSource(Integer actSource) {
        this.actSource = actSource;
    }

    /**
     * planType.
     *
     * @return the planType
     * @since JDK 1.6
     */
    public Integer getPlanType() {
        return planType;
    }

    /**
     * planType.
     *
     * @param planType the planType to set
     * @since JDK 1.6
     */
    public void setPlanType(Integer planType) {
        this.planType = planType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public Integer getActivityStatus() {
        return activityStatus;
    }

    public void setActivityStatus(Integer activityStatus) {
        this.activityStatus = activityStatus;
    }

    public Long getOperatorActivityId() {
        return operatorActivityId;
    }

    public void setOperatorActivityId(Long operatorActivityId) {
        this.operatorActivityId = operatorActivityId;
    }

    public String getReleaseTime() {
        return releaseTime;
    }

    public void setReleaseTime(String releaseTime) {
        this.releaseTime = releaseTime;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Integer getLaunchType() {
		return launchType;
	}

	public void setLaunchType(Integer launchType) {
		this.launchType = launchType;
	}

    public Integer getSubActivityWay() {
        return subActivityWay;
    }

    public void setSubActivityWay(Integer subActivityWay) {
        this.subActivityWay = subActivityWay;
    }

    public Integer getShieldActTagFlag() {
        return shieldActTagFlag;
    }

    public void setShieldActTagFlag(Integer shieldActTagFlag) {
        this.shieldActTagFlag = shieldActTagFlag;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getOverseas() {
        return overseas;
    }

    public void setOverseas(Integer overseas) {
        this.overseas = overseas;
    }

    public Long getRegionId() {
        return regionId;
    }

    public void setRegionId(Long regionId) {
        this.regionId = regionId;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public Byte getActPlanStatus() {
        return actPlanStatus;
    }

    public void setActPlanStatus(final Byte actPlanStatus) {
        this.actPlanStatus = actPlanStatus;
    }

    public Byte getBelongToGroup() {
        return belongToGroup;
    }

    public void setBelongToGroup(final Byte belongToGroup) {
        this.belongToGroup = belongToGroup;
    }

    public Integer getShieldActSkinTagFlag() {
        return shieldActSkinTagFlag;
    }

    public void setShieldActSkinTagFlag(Integer shieldActSkinTagFlag) {
        this.shieldActSkinTagFlag = shieldActSkinTagFlag;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> ssp-center-api-0.6.79-sjq-20200319.123745-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActivityManualPlanDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.util.List;

/**
 * ActivityManualPlanDto
 */
public class ActivityManualPlanDto extends BaseDto {

    private static final long serialVersionUID = -5433858401741977928L;

    /** 未开始 */
    public static final int   STATUS_PREVIEW   = 0;

    /** 正在投放 */
    public static final int   STATUS_RELEASE   = 1;

    /** 已过期 */
    public static final int   STATUS_EXPIRED   = 2;

    /** 计划类型 0-活动 */
    public static final int   PLAN_TYPE_ACT    = 0;

    /** 计划类型 1-主会场 */
    public static final int   PLAN_TYPE_VENUE  = 1;

    private Long              activityId;

    private Integer           activityType;

    private String            activityName;

    private String            activityUrl;

    private Integer           activityStatus;

    private Long              operatorActivityId;

    private String            releaseTime;

    private Integer           status;

    private Long              slotId;

    private Integer           planType;

    /** 活动来源 0-兑吧 1-推啊 2-流量引导页 */
    private Integer           actSource;

    /** 手动投放 投放方式 0 轮询，1 定时 */
    private Integer           launchType;

    /** 测试广告位子投放方式: 仅投1 优投人工2 优投算法3 纯算法4 其他0 */
    private Integer           subActivityWay;

    /** 屏蔽活动状态 */
    private Integer           shieldActTagFlag;

    /** 活动皮肤类型 */
    private String            subType;

    /** 活动皮肤名称 */
    private String            skinName;

    /** 是否是海外活动 0正常 1海外 */
    private Integer           overseas;

    /**
     * 活动测试计划ID
     */
    private Long              planId;

    /**
     * 是否是测试活动类型
     */
    private Integer           isTestActivityType;

    /**
     * 广告位地域类型ID
     */
    private Long regionId;

    /**
     * 是否支持增值 0-否 1-是
     */
    private Integer isEnc;

    /**
     * 所属组
     */
    private Byte belongToGroup;

    /**
     * 定时投放活动 测试开关
     */
    private Byte actPlanStatus;

    private Boolean  notice = false;

    /** 屏蔽活动皮肤状态 1-被当前广告位屏蔽 */
    private Integer shieldActSkinTagFlag;

    /** 是否匹配行业标签 */
    private Integer             isMatchTradeTag;

    /** 活动行业标签列表 */
    private List<TagLibraryDto> activityTradeTagList;

    private String algoType;  //算法类型
    private Long testPlanId;  //测试计划id

    /**
     * 预警文案
     */
    private String prewarningContent;

    public String getAlgoType() {
        return algoType;
    }

    public void setAlgoType(String algoType) {
        this.algoType = algoType;
    }

    public Long getTestPlanId() {
        return testPlanId;
    }

    public void setTestPlanId(Long testPlanId) {
        this.testPlanId = testPlanId;
    }

    public Boolean getNotice() {
        return notice;
    }

    public void setNotice(Boolean notice) {
        this.notice = notice;
    }


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Integer getIsTestActivityType() {
        return isTestActivityType;
    }

    public void setIsTestActivityType(Integer isTestActivityType) {
        this.isTestActivityType = isTestActivityType;
    }

    /**
     * actSource.
     *
     * @return the actSource
     * @since JDK 1.6
     */
    public Integer getActSource() {
        return actSource;
    }

    /**
     * actSource.
     *
     * @param actSource the actSource to set
     * @since JDK 1.6
     */
    public void setActSource(Integer actSource) {
        this.actSource = actSource;
    }

    /**
     * planType.
     *
     * @return the planType
     * @since JDK 1.6
     */
    public Integer getPlanType() {
        return planType;
    }

    /**
     * planType.
     *
     * @param planType the planType to set
     * @since JDK 1.6
     */
    public void setPlanType(Integer planType) {
        this.planType = planType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public Integer getActivityStatus() {
        return activityStatus;
    }

    public void setActivityStatus(Integer activityStatus) {
        this.activityStatus = activityStatus;
    }

    public Long getOperatorActivityId() {
        return operatorActivityId;
    }

    public void setOperatorActivityId(Long operatorActivityId) {
        this.operatorActivityId = operatorActivityId;
    }

    public String getReleaseTime() {
        return releaseTime;
    }

    public void setReleaseTime(String releaseTime) {
        this.releaseTime = releaseTime;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Integer getLaunchType() {
		return launchType;
	}

	public void setLaunchType(Integer launchType) {
		this.launchType = launchType;
	}

    public Integer getSubActivityWay() {
        return subActivityWay;
    }

    public void setSubActivityWay(Integer subActivityWay) {
        this.subActivityWay = subActivityWay;
    }

    public Integer getShieldActTagFlag() {
        return shieldActTagFlag;
    }

    public void setShieldActTagFlag(Integer shieldActTagFlag) {
        this.shieldActTagFlag = shieldActTagFlag;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getOverseas() {
        return overseas;
    }

    public void setOverseas(Integer overseas) {
        this.overseas = overseas;
    }

    public Long getRegionId() {
        return regionId;
    }

    public void setRegionId(Long regionId) {
        this.regionId = regionId;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public Byte getActPlanStatus() {
        return actPlanStatus;
    }

    public void setActPlanStatus(final Byte actPlanStatus) {
        this.actPlanStatus = actPlanStatus;
    }

    public Byte getBelongToGroup() {
        return belongToGroup;
    }

    public void setBelongToGroup(final Byte belongToGroup) {
        this.belongToGroup = belongToGroup;
    }

    public Integer getShieldActSkinTagFlag() {
        return shieldActSkinTagFlag;
    }

    public void setShieldActSkinTagFlag(Integer shieldActSkinTagFlag) {
        this.shieldActSkinTagFlag = shieldActSkinTagFlag;
    }

    public Integer getIsMatchTradeTag() {
        return isMatchTradeTag;
    }

    public void setIsMatchTradeTag(Integer isMatchTradeTag) {
        this.isMatchTradeTag = isMatchTradeTag;
    }

    public List<TagLibraryDto> getActivityTradeTagList() {
        return activityTradeTagList;
    }

    public void setActivityTradeTagList(List<TagLibraryDto> activityTradeTagList) {
        this.activityTradeTagList = activityTradeTagList;
    }

    public String getPrewarningContent() {
        return prewarningContent;
    }

    public void setPrewarningContent(String prewarningContent) {
        this.prewarningContent = prewarningContent;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
